#[non_exhaustive]pub struct RefutationReport {
pub refuter: Arc<str>,
pub original_ate: f64,
pub refuted_ate: f64,
pub comparison: f64,
pub informative: bool,
pub passed: bool,
pub failure_condition: Option<Arc<str>>,
pub replicates: u32,
}Expand description
Comparison of original vs refuted estimates.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.refuter: Arc<str>Refuter id.
original_ate: f64Original ATE.
refuted_ate: f64Refuted / transformed ATE (mean across replicates when applicable).
comparison: f64Scale-free comparison statistic. Replicate-based refuters store the two-sided p-value of the null value under the replicate distribution; sensitivity grids store the robustness value; overlap/e-value checks store their own statistic.
informative: boolWhether the check is informative for the estimator used.
passed: boolWhether the check passed the configured threshold.
failure_condition: Option<Arc<str>>Failure condition description when passed is false.
replicates: u32Number of replicate estimates.
Implementations